==> healthrian_visualization_support-1.0.15.tar.gz: lib/src/widgets/wear_ecg_12/ecg_waerecg.dart <==
// ignore_for_file: public_member_api_docs

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';
import 'package:healthrian_visualization_support/'
    'healthrian_visualization_support.dart';

part 'ecg_waerecg.g.dart';

@CopyWith()
class EcgWearECG extends StatelessWidget {
  const EcgWearECG({
    super.key,
    this.onLoadingWidget,
    this.height = 50,
    this.color = Colors.black,
    this.measureTime = 5,
    this.wrapperWidget,
    this.pivotColor = Colors.red,
  });

  final double measureTime;
  final Color color;
  final double height;
  final Widget? onLoadingWidget;
  final Color pivotColor;

  final Widget Function(List<Widget>)? wrapperWidget;

  @override
  Widget build(BuildContext context) {
    final streams = BLEManager().manageWearEcg12.streams;
    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder(
          stream: streams.bufferedPlotRTStreamEcg,
          builder: (context, snapshot) {
            if (!snapshot.hasData) {
              return onLoadingWidget ?? const Text('No Stream');
            }

            final list = snapshot.data!.toList();
            final pivot = snapshot.data!.pivot;

            final children = [
              for (final channel in list)
                SizedBox(
                  width: MediaQuery.of(context).size.width,
                  height: height,
                  child: ChannelWithPivot(
                    ecgSequence: channel,
                    color: color,
                    measureTime: measureTime,
                    pivot: pivot,
                    pivotColor: pivotColor,
                  ),
                ),
            ];

            if (wrapperWidget == null) {
              return Column(
                children: children,
              );
            }
            return wrapperWidget!(children);
          },
        );
      },
    );
  }
}

==> healthrian_visualization_support-1.1.1.tar.gz: lib/src/widgets/wear_ecg_12/ecg_waerecg.dart <==
// ignore_for_file: public_member_api_docs

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';
import 'package:healthrian_visualization_support/'
    'healthrian_visualization_support.dart';

part 'ecg_waerecg.g.dart';

@CopyWith()
class EcgWearECG extends StatelessWidget {
  const EcgWearECG({
    super.key,
    this.onLoadingWidget,
    this.height = 50,
    this.color = Colors.black,
    this.measureTime = 5,
    this.wrapperWidget,
    this.pivotColor = Colors.transparent,
    this.pivotStrokeWidth = 0,
    this.backgroundColor = Colors.transparent,
  });

  final double measureTime;
  final Color color;
  final double height;
  final Widget? onLoadingWidget;
  final Color pivotColor;
  final double pivotStrokeWidth;

  final Color backgroundColor;

  final Widget Function(List<Widget>)? wrapperWidget;

  @override
  Widget build(BuildContext context) {
    final streams = BLEManager().manageWearEcg12.streams;
    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder(
          stream: streams.bufferedPlotRTStreamEcg,
          builder: (context, snapshot) {
            if (!snapshot.hasData) {
              return onLoadingWidget ?? const Text('No Stream');
            }

            final list = snapshot.data!.toList();
            final pivot = snapshot.data!.pivot;

            final children = [
              for (final channel in list)
                SizedBox(
                  width: MediaQuery.of(context).size.width,
                  height: height,
                  child: ChannelWithPivot(
                    ecgSequence: channel,
                    color: color,
                    measureTime: measureTime,
                    pivot: pivot,
                    pivotColor: pivotColor,
                    pivotStrokeWidth: pivotStrokeWidth,
                    backgroundColor: backgroundColor,
                  ),
                ),
            ];

            if (wrapperWidget == null) {
              return Column(
                children: children,
              );
            }
            return wrapperWidget!(children);
          },
        );
      },
    );
  }
}
